@@ -100,7 +100,7 @@ def get_key(data, key):
         raise Exception("unexpected failure")
 
 
-def create_edit_issue(issue=None):
+def create_edit_issue(issue=None, text=None):
     main_text = """# Please explain the issue.
 # The first line will be used as the title.
 # Lines starting with `#` will be ignored."""
@@ -117,9 +117,13 @@ def create_edit_issue(issue=None):
 #   created:  %(created_at)s""" % issue
     else:
         template = "\n%s" % main_text
-    text = edit_text(template)
-    if not text:
-        raise Exception("can not submit an empty issue")
+    if text:
+        # \n on the command-line becomes \\n; undoing this:
+        text = text.replace("\\n", "\n")
+    else:
+        text = edit_text(template)
+        if not text:
+            raise Exception("can not submit an empty issue")
     lines = text.splitlines()
     title = lines[0]
     body = "\n".join(lines[1:]).strip()
@@ -237,8 +241,8 @@ class Commands(object):
                 printer.write("\n".join(lines))
             printer.close()
 
-    def open(self, **kwargs):
-        post_data = create_edit_issue()
+    def open(self, message=None, **kwargs):
+        post_data = create_edit_issue(text=message)
         result = self.__submit('open', data=post_data)
         issue = get_key(result, 'issue')
         pprint_issue(issue)
@@ -331,6 +335,9 @@ Examples:
 %prog <nr> -w                         show issue <nr>'s GitHub page in web
                                     browser
 %prog open (o)                        create a new issue (with $EDITOR)
+%prog open (o) -m <msg>               create a new issue with <msg> content 
+                                    (optionally, use \\n for new lines; first 
+                                    line will be the issue title)
 %prog close (c) <nr>                  close issue <nr>
 %prog open (o) <nr>                   reopen issue <nr>
 %prog edit (e) <nr>                   edit issue <nr> (with $EDITOR)
@@ -358,6 +365,9 @@ command-line interface to GitHub's Issues API (v2)"""
         default='open', help="specify state (only for list and search "\
         "(except `all`) commands) choices are: open (o), closed (c), all "\
         "(a) [default: open]")
+    parser.add_option("-m", "--message", action="store", dest="message",
+      default=None, help="message content for opening an issue without "\
+        "using the editor")
     parser.add_option("-r", "--repo", "--repository", action="store",
         dest="repo", help="specify a repository (format: "\
             "`user/repo` or just `repo` (latter will get the user from the "\
